# FulfillmentType

The type of the Fulfillment.  

## Enum

* `DELIVERY` (value: `'Delivery'`)

* `RETURN` (value: `'Return'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


